Imports Microsoft.VisualBasic
Imports System
Imports System.Data
Imports System.Drawing
Imports System.Windows.Forms
Imports O2S.Barcode4NET

Namespace BarcodeGridColumn
	''' <summary>
	''' Represents a barcode column.
	''' </summary>
	Public Class DataGridBarcodeColumn
		Inherits DataGridTextBoxColumn
		''' <summary>
		''' Initializes a new <see cref="DataGridBarcodeColumn"/> object.
		''' </summary>
		Public Sub New()
		End Sub

		''' <summary>
		''' 
		''' </summary>
		''' <param name="g"></param>
		''' <param name="bounds"></param>
		''' <param name="source"></param>
		''' <param name="rowNum"></param>
		''' <param name="backBrush"></param>
		''' <param name="foreBrush"></param>
		''' <param name="alignToRight"></param>
		Protected Overrides Overloads Sub Paint(ByVal g As System.Drawing.Graphics, ByVal bounds As System.Drawing.Rectangle, ByVal source As CurrencyManager, ByVal rowNum As Integer, ByVal backBrush As System.Drawing.Brush, ByVal foreBrush As System.Drawing.Brush, ByVal alignToRight As Boolean)
			' Paint the background.
			g.FillRectangle(backBrush, bounds)

			' Get the row to paint.
			Dim dr As DataRow = (CType(source.List, DataView)).Table.Rows(rowNum)
			' Get the string to display.
			Dim displayItem As String = dr(MappingName).ToString()

#If _1D Then
			Try
				' We use a Code 39 barcode to display the customer id.
				Dim c39 As Code39Barcode = New Code39Barcode(displayItem)
				c39.DimensionUnit = XYDimensionUnit.Pixel
				c39.XDimension = 1
				c39.YDimension = 50
				c39.DataDisplayLocation = BarcodeTextLocation.BelowEmbedded

				' Get the barcode size.
				Dim barcodeSize As SizeF = c39.GetSize(g.DpiX, g.DpiY)

				' Draw the barcode inside the cell.
				c39.Draw(g, (bounds.Left + bounds.Right - barcodeSize.Width)/2, bounds.Top + 3)
			Catch
				' If the barcode data is invalid, nothing is displayed.
			End Try
#End If
#If _2D Then
			Try
				' Use a DataMatrix barcode for the strings in the list.
				Dim dm As DataMatrixBarcode = New DataMatrixBarcode()
				dm.Data = displayItem
				dm.DimensionUnit = XYDimensionUnit.Pixel
				dm.XDimension = 3

				' Get the size of the barcode.
				Dim barcodeSize As SizeF = dm.GetSize(g.DpiX, g.DpiY)

				Dim rowHeight As Integer = DataGridTableStyle.PreferredRowHeight
				' Draw the barcode left aligned in the list.
				dm.Draw(g, bounds.Left + 3, bounds.Top + (rowHeight - barcodeSize.Height)/2)

				' Draw the barcode text.
				Dim font As Font = New Font("Tahoma", 8, FontStyle.Bold, GraphicsUnit.Point)
				g.DrawString(displayItem, font, SystemBrushes.ControlText, bounds.Left + 6 + barcodeSize.Width, bounds.Top + (rowHeight - barcodeSize.Height)/2)
				font.Dispose()
			Catch
				' If the barcode data is invalid, nothing is displayed.
			End Try
#End If

		End Sub
	End Class
End Namespace
